@@ -2,8 +2,6 @@
 ## May 6, 2022
 
 """
-██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██
-  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██
 ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██
   ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██
 
@@ -16,12 +14,12 @@
                 █ ██
                        🏁 Retrieve NWP Model Data 🏁
 
-██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██
-  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██
 ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██
   ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██  ██
 """
 
+from herbie import Path
+
 
 class hc:
     """Herbie Color Pallette"""
@@ -37,8 +35,8 @@ class ANSI:
     """
     Herbie colors as ansi codes
 
-    Reference
-    ---------
+    Notes
+    -----
     https://gist.github.com/fnky/458719343aabd01cfb17a3a4f7296797
 
     """
