@@ -32,7 +32,7 @@ PRODUCTS : dict
 SOURCES : dict
     Build the URL for the GRIB2 file for different sources.
     The parameters are from arguments passed into the
-    ``herbie.archive.Herbie()`` class.
+    ``herbie.core.Herbie()`` class.
     ORDER MATTERS -- If priority is None, then Herbie searches the
     sources in the order given here.
     *LOOP THROUGH ALL SOURCES*
@@ -56,6 +56,8 @@ IDX_STYLE : {'wgrib2', 'eccodes'}
     - NCEP products use ``wgrib2`` to create index files.
     - ECMWF products use ``eccodes`` to create index files.
 """
+__all__ = ["hrrr", "hrrrak"]
+
 from datetime import datetime
 
 
